Welcome to ClientVPS Mirrors

Help for package ggraptR
Type: Package
Title: Allows Interactive Visualization of Data Through a Web Browser GUI
Version: 1.3
Description: Intended for both technical and non-technical users to create interactive data visualizations through a web browser GUI without writing any code.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Suggests: knitr, markdown
Depends: dplyr (≥ 0.7.5), ggplot2 (≥ 2.2.0), pacman (≥ 0.4.6), purrr(≥ 0.2.4), shiny (≥ 0.12.2)
BugReports: https://github.com/cargomoose/raptR/issues
VignetteBuilder: knitr
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2020-06-24 01:11:17 UTC; juliux
Author: Eugene Dubossarsky [aut, cph, cre], Julius Neggo [ctb] (Lead Developer), Howard Song [aut] (Developer), Susan Wang [ctb] (Project Manager), Jason Widjaja [ctb] (Vignette), Jose Magana [ctb] (Package Manager and Developer), Sergey Skripko [ctb] (Developer)
Maintainer: Eugene Dubossarsky <eugene@presciient.com>
Repository: CRAN
Date/Publication: 2020-06-24 05:00:03 UTC

Launch ggraptR in the default browser

Description

Launch ggraptR in the default browser

Usage

ggraptR(initialDf = ggplot2::diamonds, ...)

Arguments

initialDf

initial dataframe to plot

...

extra arguments. Possible options are: initialPlot - a vector of plot names externalRun - a boolean to run ggraptR in a separate process any shiny::runApp arguments

Details

See http://github.com/cargomoose/raptR for documentation and tutorials

Examples

if (interactive()) {
  ggraptR(initialDf='mtcars', initialPlot=c('Scatter', 'Line'), appDir='inst/ggraptR')
}

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.